@@ -14,15 +14,14 @@ all_spct_attr.ls <-
                      "where.measured",
                      "what.measured",
                      "how.measured",
-#                     "spct.tags",
-#                     "spct.version",
                      "normalized",
                      "scaled",
-                     "multiple.wl"),
+                     "multiple.wl",
+                     "spct.idx"),
     raw_spct = c("time.unit", "linearized"),
     cps_spct = c("time.unit", "linearized"),
     source_spct = c("time.unit", "bswf.used"),
-    response_spct = c("time.unit", "bswf.used"),
+    response_spct = c("time.unit", "bswf.used", "response.type"),
     object_spct = c("Tfr.type", "Rfr.type", "filter.properties"),
     filter_spct = c("Tfr.type", "Rfr.type", "filter.properties"),
     reflector_spct = c("Tfr.type", "Rfr.type", "filter.properties"),
